"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Conversation_1 = __importDefault(require("./Conversation"));
/**
 * Hold all the direct messages contained in a Twitter GDPR archive.
 */
class DMArchive {
    constructor(me_id) {
        this.me_id = me_id;
        this.index = {};
    }
    /** Add a direct message file in current conversation object. */
    add(convs) {
        for (const conv of convs) {
            if (conv.dmConversation.messages.length) {
                if (this.has(conv.dmConversation.conversationId)) {
                    const c = this.get(conv.dmConversation.conversationId);
                    c.add(conv);
                }
                else {
                    const tmp = new Conversation_1.default(conv, this.me_id);
                    this.index[tmp.id] = tmp;
                }
            }
        }
        // Index all convs
        for (const conv of this.all) {
            conv.indexate();
        }
    }
    /** Get a conversation with specific ID. undefined if it does not exists. */
    get(id) {
        return this.index[id];
    }
    /** Test if archive has a conversation with ID {id} */
    has(id) {
        return id in this.index;
    }
    /** Group conversations */
    get groups() {
        return this.all.filter(c => c.is_group_conversation);
    }
    /** Direct (two participants) conversations */
    get directs() {
        return this.all.filter(c => !c.is_group_conversation);
    }
    /** Array of conversations registered in this archive. */
    get all() {
        return Object.values(this.index);
    }
    /** Message count. */
    get count() {
        let c = 0;
        for (const conv of this.all) {
            c += conv.length;
        }
        return c;
    }
    /** Conversation count. */
    get length() {
        return this.all.length;
    }
}
exports.DMArchive = DMArchive;
exports.default = DMArchive;
